package cn.estsh.i3plus.ext.mes.apiservice.serviceimpl.report;

import cn.estsh.i3plus.ext.mes.api.busi.report.IMesYfReportService;
import cn.estsh.i3plus.ext.mes.apiservice.dao.report.IMesYfReportDao;
import cn.estsh.i3plus.ext.mes.pojo.model.report.MesDeviceDataQueryReportConditionModel;
import cn.estsh.i3plus.ext.mes.pojo.model.report.MesDeviceDataQueryReportResultModel;
import cn.estsh.i3plus.ext.mes.pojo.model.report.MesProdRuleReportConditionModel;
import cn.estsh.i3plus.pojo.base.bean.DdlPackBean;
import cn.estsh.i3plus.pojo.base.bean.ListPager;
import cn.estsh.i3plus.pojo.base.common.Pager;
import cn.estsh.i3plus.pojo.base.common.PagerHelper;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.enumutil.ResourceEnumUtil;
import cn.estsh.i3plus.pojo.base.tool.DdlPreparedPack;
import cn.estsh.i3plus.pojo.mes.bean.MesProdRuleNosortCfg;
import cn.estsh.i3plus.pojo.mes.bean.MesProdRuleSortCfg;
import cn.estsh.i3plus.pojo.mes.bean.MesProduceSn;
import cn.estsh.i3plus.pojo.mes.repository.MesProdRuleNoSortCfgRepository;
import cn.estsh.i3plus.pojo.mes.repository.MesProdRuleSortCfgRepository;
import cn.estsh.i3plus.pojo.mes.repository.MesProduceSnRepository;
import cn.estsh.i3plus.pojo.mes.util.MesExtEnumUtil;
import cn.estsh.impp.framework.boot.util.ResultBean;
import jodd.util.StringUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Description : 报表-业务方法实现
 * @Reference :
 * @Author : logic
 * @CreateDate : 2024/6/15 11:31
 * @Modify:
 **/
@Service
public class MesYfReportServiceImpl implements IMesYfReportService {

    @Autowired
    private IMesYfReportDao mesYfReportDao;

    @Autowired
    private MesProduceSnRepository mesProduceSnRDao;

    @Autowired
    private MesProdRuleSortCfgRepository mesProdRuleSortCfgRepository;

    @Autowired
    private MesProdRuleNoSortCfgRepository mesProdRuleNoSortCfgRepository;

    @Override
    public ListPager<MesDeviceDataQueryReportResultModel> queryMesDeviceDataByPager(MesDeviceDataQueryReportConditionModel queryReportModel, Pager pager) {
        ListPager<MesDeviceDataQueryReportResultModel> mesDeviceDataQueryReportResultModelListPager =
                mesYfReportDao.queryMesDeviceDataByPager(queryReportModel, pager);
        List<MesDeviceDataQueryReportResultModel> objectList = mesDeviceDataQueryReportResultModelListPager.getObjectList();
        for (MesDeviceDataQueryReportResultModel model : objectList) {
            model.setLogTypeName(MesExtEnumUtil.LOG_TYPE.valueOfDescription(model.getLogType()));
        }
        return new ListPager<>(objectList, mesDeviceDataQueryReportResultModelListPager.getObjectPager());
    }

    @Override
    public ResultBean queryMesProdRuleByPager(MesProdRuleReportConditionModel queryReportModel, Pager pager) {
        DdlPackBean queryPackBean = DdlPackBean.getDdlPackBean(queryReportModel.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(queryReportModel.getEquipmentCode(), "equipmentCode", queryPackBean);
        if (CommonEnumUtil.TRUE_OR_FALSE.TRUE.getValue() == queryReportModel.getIsSort()) {
            //查询“排序产品加工规则配置”
            DdlPreparedPack.getStringEqualPack(queryReportModel.getWorkCenterCode(), "workCenterCode", queryPackBean);
            DdlPreparedPack.getStringEqualPack(queryReportModel.getWorkCellCode(), "workCellCode", queryPackBean);
            pager = PagerHelper.getPager(pager, mesProdRuleSortCfgRepository.findByHqlWhereCount(queryPackBean));
            List<MesProdRuleSortCfg> mesProdRuleSortCfgList = mesProdRuleSortCfgRepository.findByHqlWherePage(queryPackBean, pager);
            return ResultBean.success("查询设备数据成功").setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode()).setListPager(new ListPager(mesProdRuleSortCfgList, pager));
        }else {
            //查询“非排序产品加工规则配置”
            DdlPreparedPack.getStringEqualPack(queryReportModel.getInPartNo(), "inPartNo", queryPackBean);
            DdlPreparedPack.getStringEqualPack(queryReportModel.getInPartNoRule(), "inPartNoRule", queryPackBean);
            DdlPreparedPack.getStringEqualPack(queryReportModel.getOutPartNo(), "outPartNo", queryPackBean);
            pager = PagerHelper.getPager(pager, mesProdRuleNoSortCfgRepository.findByHqlWhereCount(queryPackBean));
            List<MesProdRuleNosortCfg> mesProdRuleNosortCfgList = mesProdRuleNoSortCfgRepository.findByHqlWherePage(queryPackBean, pager);
            return ResultBean.success("查询设备数据成功").setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode()).setListPager(new ListPager(mesProdRuleNosortCfgList, pager));
        }
    }


    @Override
    public ListPager<MesProduceSn> queryMesSuspiciousSnMsgByPager(MesProduceSn bean, Pager pager) {
        DdlPackBean packBean = DdlPackBean.getDdlPackBean(bean.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(bean.getPartNo(), "partNo", packBean);
        DdlPreparedPack.getStringLikerPack(bean.getPartName(), "partName", packBean);
        DdlPreparedPack.getNumEqualPack(bean.getQcStatus(), "qcStatus", packBean);
        DdlPreparedPack.getStringEqualPack(bean.getWorkCenterCode(), "workCenterCode", packBean);
        DdlPreparedPack.getStringEqualPack(bean.getProductSn(), "productSn", packBean);
        DdlPreparedPack.getStringEqualPack(bean.getLotNo(), "lotNo", packBean);
        if(!StringUtil.isEmpty(bean.orderBy())){
            packBean.setOrderByStr(bean.orderBy());
        }else {
            DdlPreparedPack.getOrderByPack(new Object[]{CommonEnumUtil.ASC_OR_DESC.DESC.getValue()}, new String[]{"createDatetime"}, packBean);
        }
        pager = PagerHelper.getPager(pager, mesProduceSnRDao.findByHqlWhereCount(packBean));

        List<MesProduceSn> resultList = mesProduceSnRDao.findByHqlWherePage(packBean, pager);

        return new ListPager<>(resultList, pager);
    }
}
